@@ -98,6 +98,22 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             "types_or": ["json", "yaml"],
         },
     },
+    "compose-spec": {
+        "url": _githubusercontent_url(
+            "compose-spec",
+            "compose-spec",
+            "master",
+            "schema/compose-spec.json",
+        ),
+        "hook_config": {
+            "name": "Validate Docker Compose files",
+            "files": [
+                r"([^/]*/)*docker-compose(\.[\.a-zA-Z0-9_-]*)*\.(yml|yaml)",
+                r"([^/]*/)*compose(\.[\.a-zA-Z0-9_-]*)*\.(yml|yaml)",
+            ],
+            "types": "yaml",
+        },
+    },
     "dependabot": {
         "url": "https://json.schemastore.org/dependabot-2.0.json",
         "hook_config": {
@@ -140,7 +156,12 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
         ),
         "hook_config": {
             "name": "Validate GitLab CI config",
-            "add_args": ["--data-transform", "gitlab-ci"],
+            "add_args": [
+                "--data-transform",
+                "gitlab-ci",
+                "--regex-variant",
+                "nonunicode",
+            ],
             "files": r"^.*\.gitlab-ci\.yml$",
             "types": "yaml",
         },
@@ -182,6 +203,7 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
                 "Validate Renovate config against the schema provided by "
                 "Renovate (does not support renovate config in package.json)"
             ),
+            "add_args": ["--regex-variant", "nonunicode"],
             "files": [
                 r"renovate\.(json|json5)",
                 r"\.(github|gitlab)/renovate\.(json|json5)",
